% function FS=computesubsetFDFST(lf,subsample,ext,Np)
% DESCRIPTION Computes the subset Fast Discrete Focal Stack transform
% expanding the borders of the image to alleviate vignetting effects (easy but not
% the best way to do it)
% INPUT: lf, lightfield with Nxy x Nxy microlenses, Nuv x Nuv
% pixels behind each microlens and nbands per pixel (nbands=3 for color images) 
% stored in a [Nxy,Nxy,Nuv,Nuv,nbands] array . 
% lf can be obtained from an image using the read_lightfield3 function.
% subsample, spatial subsampling factor for lf (useful for out of memory
% problems)
% ext, number of rows and cols to specularly append to the borders of the image (to
% avoid vignetting problems)
% Np, number of planes, it has to obey the following constraints
% Np has to be odd
% Np-1 has to divide (Nxy-Nxyodd +2*floor((Nuv+2)/4))*(Nuv-Nuvodd)
% Nxyodd=1, Nuvodd =1 if the number is odd , zero otherwise
% Input Np is increased until it verifies the constraint.
% OUTPUT: FS, focal stack  from the lightfield computed with the subset Fast Discrete
% Focal Stack Transform (DFST) stored in a [Nxy,Nxy,nbands,Np] array


function FS=computesubsetFDFST(lf,subsample,ext,Np)


[Nxy,Nxy,Nuv,Nuv,nbands]=size(lf);
lf=lf(1:subsample:Nxy,1:subsample:Nxy,:,:,:);
[Nxy,Nxy,Nuv,Nuv,nbands]=size(lf);
llf=zeros([Nxy+2*ext,Nxy+2*ext,Nuv,Nuv,nbands]);

for i=1:Nuv
    for j=1:Nuv
        llf(1:ext,ext+1:ext+Nxy,i,j,:)=lf(ext:-1:1,:,i,j,:);
        llf(Nxy+1+ext:Nxy+2*ext,ext+1:ext+Nxy,i,j,:)=lf(Nxy:-1:Nxy-ext+1,:,i,j,:);
        llf(ext+1:ext+Nxy,1:ext,i,j,:)=lf(:,ext:-1:1,i,j,:);
        llf(ext+1:ext+Nxy,Nxy+1+ext:Nxy+2*ext,i,j,:)=lf(:,Nxy:-1:Nxy-ext+1,i,j,:);
        llf(ext+1:Nxy+ext,ext+1:Nxy+ext,i,j,:)=lf(:,:,i,j,:);
    end
end

clear lf
pack

EFS=subsetFDFST(llf,Np);
[tmp,tmp,nbands,Np]=size(EFS);
FS=zeros([Nxy,Nxy,nbands,Np]);
FS=EFS(ext+1:Nxy+ext,ext+1:Nxy+ext,:,:);


return;