% function lf=read_lightfield3(im,Nxy,Nuv)
% DESCRIPTION: stores a lightfield image into an array
% INPUT: im, image from a color plenoptic camera with Nxy x Nxy microlenses and  Nuv x Nuv
% pixels behind each microlens stored in a [Nxy*Nuv,Nxy*Nuv,3] array.
% OUTPUT: lf, lightfield with Nxy x Nxy microlenses, Nuv x Nuv
% pixels behind each microlens and 3 bands per pixel (Red, Green, Blue) 
% stored in a [Nxy,Nxy,Nuv,Nuv,nbands] array .

function lf=read_lightfield3(im,Nxy,Nuv)
nuv=floor(Nuv/2);
Nuveven=(Nuv/2==nuv);
lf=zeros([Nxy,Nxy,Nuv,Nuv,3],'uint8');
for bands=1:3
    for uvrow=-nuv:nuv-Nuveven
        for uvcol=-nuv:nuv-Nuveven
            lf(:,:,uvrow+nuv+1,uvcol+nuv+1,bands)=im(uvrow+nuv+1+[0:Nuv:Nxy*Nuv-1],uvcol+nuv+1+[0:Nuv:Nxy*Nuv-1],bands);
        end
    end
end
end